@@ -4,13 +4,13 @@ from Orange.data import Table, ContinuousVariable
 from Orange.widgets import widget, gui, settings
 
 import numpy as np
-from PyQt4.QtGui import QListWidget
+from AnyQt.QtWidgets import QListWidget
 
 from orangecontrib.timeseries.util import cache_clears
 from orangecontrib.timeseries import (
     Timeseries, periodogram as periodogram_equispaced, periodogram_nonequispaced
 )
-from Orange.widgets.highcharts import Highchart
+from orangecontrib.timeseries.widgets.highcharts import Highchart
 
 
 class OWPeriodogram(widget.OWWidget):
@@ -24,6 +24,8 @@ class OWPeriodogram(widget.OWWidget):
 
     attrs = settings.Setting([])
 
+    graph_name = 'plot'
+
     def __init__(self):
         self.all_attrs = []
         gui.listBox(self.controlArea, self, 'attrs',
@@ -106,12 +108,13 @@ class OWPeriodogram(widget.OWWidget):
 
 
 if __name__ == "__main__":
-    from PyQt4.QtGui import QApplication
+    from AnyQt.QtWidgets import QApplication
 
     a = QApplication([])
     ow = OWPeriodogram()
 
-    data = Table('iris')
+    data = Timeseries('yahoo_MSFT')
+    data = Timeseries('autoroute')
     # data = Timeseries('UCI-SML2010-1')
     ow.set_data(data)
 
