@@ -10,16 +10,17 @@ from Orange.util import color_to_hex
 
 from Orange.data import Table, Domain, TimeVariable, DiscreteVariable
 from Orange.widgets import widget, gui, settings
-from Orange.widgets.highcharts import Highchart
 from Orange.widgets.utils.colorpalette import GradientPaletteGenerator
 from Orange.widgets.utils.itemmodels import VariableListModel
 
 from orangecontrib.timeseries.widgets.utils import ListModel
 from orangecontrib.timeseries import Timeseries
 from orangecontrib.timeseries.agg_funcs import AGG_FUNCTIONS, Mode
+from orangecontrib.timeseries.widgets.highcharts import Highchart
 
-from PyQt4.QtGui import QListView, QItemSelectionModel
-from PyQt4.QtGui import QColor
+from AnyQt.QtWidgets import QListView
+from AnyQt.QtCore import QItemSelectionModel
+from AnyQt.QtGui import QColor
 
 class Spiralogram(Highchart):
     """
@@ -96,6 +97,9 @@ class Spiralogram(Highchart):
         for i, tval in enumerate(time_values):
             indices[(xfunc(i, tval), yfunc(i, tval))].append(i)
 
+        if self._owwidget.invert_date_order:
+            yvals = yvals[::-1]
+
         series = []
         aggvals = []
         self.indices = []
@@ -249,6 +253,8 @@ class Spiralogram(Highchart):
                          javascript=javascript,
                          **kwargs)
         self.indices = {}
+        assert isinstance(parent, widget.OWWidget)
+        self._owwidget = parent
 
 
 def _enum_str(enum_value, inverse=False):
@@ -270,9 +276,14 @@ class OWSpiralogram(widget.OWWidget):
 
     ax1 = settings.ContextSetting('months of year')
     ax2 = settings.ContextSetting('years')
+
     agg_attr = settings.ContextSetting([])
     agg_func = settings.ContextSetting(0)
 
+    invert_date_order = settings.Setting(False)
+
+    graph_name = 'chart'
+
     def __init__(self):
         self.data = None
         self.indices = []
@@ -283,6 +294,9 @@ class OWSpiralogram(widget.OWWidget):
         self.combo_ax1 = gui.comboBox(
             box, self, 'ax1', label='Radial:', callback=self.replot,
             sendSelectedValue=True, orientation='horizontal')
+        gui.checkBox(box, self, 'invert_date_order', 'Invert Y axis order',
+                     callback=self.replot)
+
         box = gui.vBox(self.controlArea, 'Aggregation')
         self.combo_func = gui.comboBox(
             box, self, 'agg_func', label='Function:', orientation='horizontal',
@@ -296,7 +310,9 @@ class OWSpiralogram(widget.OWWidget):
         self.attrlist.selectionModel().selectionChanged.connect(
             self.attrlist_selectionChanged)
         box.layout().addWidget(self.attrlist)
+
         gui.rubber(self.controlArea)
+
         self.chart = chart = Spiralogram(self,
                                          selection_callback=self.on_selection)
         self.mainArea.layout().addWidget(chart)
@@ -387,7 +403,7 @@ class OWSpiralogram(widget.OWWidget):
 
 
 if __name__ == "__main__":
-    from PyQt4.QtGui import QApplication
+    from AnyQt.QtWidgets import QApplication
 
     a = QApplication([])
     ow = OWSpiralogram()
